// Copyright (C) 1999-2005 Open Source Telecom Corporation.
// Copyright (C) 2006-2008 David Sugar, Tycho Softworks.
//
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; either version 2 of the License, or
// (at your option) any later version.
//
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
//
// As a special exception, you may use this file as part of a free software
// library without restriction.  Specifically, if other files instantiate
// templates or use macros or inline functions from this file, or you compile
// this file and link it with other files to produce an executable, this
// file does not by itself cause the resulting executable to be covered by
// the GNU General Public License.  This exception does not however
// invalidate any other reasons why the executable file might be covered by
// the GNU General Public License.
//
// This exception applies only to the code released under the name GNU
// Common C++.  If you copy code from other releases into a copy of GNU
// Common C++, as the General Public License permits, the exception does
// not apply to the code that you add in this way.  To avoid misleading
// anyone as to the status of such modified files, you must delete
// this exception notice from them.
//
// If you write modifications of your own for GNU Common C++, it is your choice
// whether to permit this exception to apply to your modifications.
// If you do not wish that, delete this exception notice.
//
/**
 * @file common.h
 * @short GNU Common C++ global header.
 **/

#ifndef	CCXX_COMMON_H_
#define	CCXX_COMMON_H_

#include <cc++/config.h>
#ifdef	CCXX_EXPORT_LIBRARY
#include <cc++/export.h>
#endif
#include <cc++/missing.h>
#include <cc++/strchar.h>
#include <cc++/exception.h>
#include <cc++/thread.h>
#include <cc++/process.h>
#include <cc++/slog.h>
#include <cc++/file.h>
#include <cc++/address.h>
#include <cc++/socket.h>
#include <cc++/network.h>
#include <cc++/misc.h>
#include <cc++/digest.h>
#include <cc++/numbers.h>
#include <cc++/persist.h>
#include <cc++/serial.h>
#include <cc++/string.h>
#include <cc++/cmdoptns.h>
#include <cc++/url.h>
#include <cc++/xml.h>
#endif

/**
 * @mainpage GNU Common C++ Reference Manual
 **/

/**
 * @example urlfetch.cpp
 **/

/**
 * @example xmlfetch.cpp
 **/

/**
 * @example slogTest.cpp
 **/

/**
 * @example tcp.cpp
 **/

/**
 * @example tcpthread.cpp
 **/

/**
 * @example tcpservice.cpp
 **/

/**
 * @example SampleSocketPort.cpp
 **/

/**
 * @example serialmain.cpp
 **/

/**
 * @example serialecho.cpp
 **/

/**
 * @example cmdlineopt.cpp
 **/

/**
 * @example crc32.cpp
 **/

/**
 * @example bug1.cpp
 **/

/**
 * @example bug2.cpp
 **/

/**
 * @example digest.cpp
 **/

/**
 * @example thread1.cpp
 **/

/**
 * @example thread2.cpp
 **/

/**
 * @example tcpstr1.cpp
 **/

/**
 * @example url1.cpp
 **/

/** EMACS **
 * Local variables:
 * mode: c++
 * c-basic-offset: 8
 * End:
 */
